@@ -1,4 +1,5 @@
-using Optimization, OptimizationOptimJL, OptimizationMOI, Ipopt, Test
+using Optimization, OptimizationOptimJL, OptimizationMOI, OptimizationLBFGSB
+using Ipopt, Test
 using ForwardDiff, Zygote, ReverseDiff, FiniteDiff, Tracker, Mooncake
 using Enzyme, Random
 
@@ -22,7 +23,7 @@ end
     optf = OptimizationFunction(rosenbrock; grad = g!, hess = h!)
 
     prob = OptimizationProblem(optf, x0)
-    sol = solve(prob, Optimization.LBFGS())
+    sol = solve(prob, OptimizationLBFGSB.LBFGSB())
 
     @test 10 * sol.objective < l1
     @test sol.retcode == ReturnCode.Success
@@ -34,8 +35,8 @@ end
 
 @testset "No constraint" begin
     @testset "$adtype" for adtype in [AutoEnzyme(), AutoForwardDiff(), AutoZygote(), AutoReverseDiff(),
-        AutoFiniteDiff(), AutoModelingToolkit(), AutoSparseForwardDiff(),
-        AutoSparseReverseDiff(), AutoSparse(AutoZygote()), AutoModelingToolkit(true, true), AutoMooncake()]
+        AutoFiniteDiff(), AutoSymbolics(), AutoSparse(AutoForwardDiff()),
+        AutoSparse(AutoReverseDiff()), AutoSparse(AutoZygote()), AutoSparse(AutoSymbolics()), AutoMooncake()]
         optf = OptimizationFunction(rosenbrock, adtype)
 
         prob = OptimizationProblem(optf, x0)
@@ -46,7 +47,7 @@ end
             @test sol.retcode == ReturnCode.Success
         end
 
-         # `Newton` requires Hession, which Mooncake doesn't support at the moment. 
+         # `Newton` requires Hession, which Mooncake doesn't support at the moment.
         if adtype != AutoMooncake()
             sol = solve(prob, Optim.Newton())
             @test 10 * sol.objective < l1
@@ -55,7 +56,7 @@ end
             end
         end
 
-        # Requires Hession, which Mooncake doesn't support at the moment. 
+        # Requires Hession, which Mooncake doesn't support at the moment.
         # Enzyme Hessian-Free seems to have an issue that is hard to track down.
         # https://github.com/SciML/Optimization.jl/issues/1030
         if adtype != AutoMooncake() && adtype != AutoEnzyme()
@@ -66,7 +67,7 @@ end
             end
         end
 
-        sol = solve(prob, Optimization.LBFGS(), maxiters = 1000)
+        sol = solve(prob, OptimizationLBFGSB.LBFGSB(), maxiters = 1000)
         @test 10 * sol.objective < l1
         @test sol.retcode == ReturnCode.Success
     end
@@ -74,18 +75,18 @@ end
 
 @testset "One constraint" begin
     @testset "$adtype" for adtype in [AutoEnzyme(), AutoForwardDiff(), AutoZygote(), AutoReverseDiff(),
-        AutoFiniteDiff(), AutoModelingToolkit(), AutoSparseForwardDiff(),
-        AutoSparseReverseDiff(), AutoSparse(AutoZygote()), AutoModelingToolkit(true, true), AutoMooncake()]
+        AutoFiniteDiff(), AutoSymbolics(), AutoSparse(AutoForwardDiff()),
+        AutoSparse(AutoReverseDiff()), AutoSparse(AutoZygote()), AutoSparse(AutoSymbolics()), AutoMooncake()]
         cons = (res, x, p) -> (res[1] = x[1]^2 + x[2]^2 - 1.0; return nothing)
         optf = OptimizationFunction(rosenbrock, adtype, cons = cons)
 
         prob = OptimizationProblem(
             optf, x0, lb = [-1.0, -1.0], ub = [1.0, 1.0], lcons = [0.0], ucons = [0.0])
 
-        sol = solve(prob, Optimization.LBFGS(), maxiters = 1000)
+        sol = solve(prob, OptimizationLBFGSB.LBFGSB(), maxiters = 1000)
         @test 10 * sol.objective < l1
 
-        # Requires Hession, which Mooncake doesn't support at the moment. 
+        # Requires Hession, which Mooncake doesn't support at the moment.
         if adtype != AutoMooncake()
             sol = solve(prob, Ipopt.Optimizer(), max_iter = 1000; print_level = 0)
             @test 10 * sol.objective < l1
@@ -95,8 +96,8 @@ end
 
 @testset "Two constraints" begin
     @testset "$adtype" for adtype in [AutoForwardDiff(), AutoZygote(), AutoReverseDiff(),
-        AutoFiniteDiff(), AutoModelingToolkit(), AutoSparseForwardDiff(),
-        AutoSparseReverseDiff(), AutoSparse(AutoZygote()), AutoModelingToolkit(true, true), AutoMooncake()]
+        AutoFiniteDiff(), AutoSymbolics(), AutoSparseForwardDiff(),
+        AutoSparseReverseDiff(), AutoSparse(AutoZygote()), AutoSparse(AutoSymbolics()), AutoMooncake()]
         function con2_c(res, x, p)
             res[1] = x[1]^2 + x[2]^2
             res[2] = x[2] * sin(x[1]) - x[1]
@@ -107,10 +108,10 @@ end
         prob = OptimizationProblem(optf, x0, lb = [-1.0, -1.0], ub = [1.0, 1.0],
             lcons = [1.0, -2.0], ucons = [1.0, 2.0])
 
-        sol = solve(prob, Optimization.LBFGS(), maxiters = 1000)
+        sol = solve(prob, OptimizationLBFGSB.LBFGSB(), maxiters = 1000)
         @test 10 * sol.objective < l1
 
-        # Requires Hession, which Mooncake doesn't support at the moment. 
+        # Requires Hession, which Mooncake doesn't support at the moment.
         if adtype != AutoMooncake()
             sol = solve(prob, Ipopt.Optimizer(), max_iter = 1000; print_level = 0)
             @test 10 * sol.objective < l1
